@@ -1,10 +1,21 @@
-# cligj
+"""cligj
 
-# Shared arguments and options.
+A package of arguments, options, and parsers for the Python GeoJSON
+ecosystem.
+"""
+
+import sys
+from warnings import warn
 
 import click
 
-# Arguments.
+from .features import normalize_feature_inputs
+
+__version__ = "0.7.0"
+
+if sys.version_info < (3, 7):
+    warn("cligj 1.0.0 will require Python >= 3.7", FutureWarning)
+
 
 # Multiple input files.
 files_in_arg = click.argument(
@@ -14,6 +25,7 @@ files_in_arg = click.argument(
     required=True,
     metavar="INPUTS...")
 
+
 # Multiple files, last of which is an output file.
 files_inout_arg = click.argument(
     'files',
@@ -22,8 +34,18 @@ files_inout_arg = click.argument(
     required=True,
     metavar="INPUTS... OUTPUT")
 
-# Options.
 
+# Features from files, command line args, or stdin.
+# Returns the input data as an iterable of GeoJSON Feature-like
+# dictionaries.
+features_in_arg = click.argument(
+    'features',
+    nargs=-1,
+    callback=normalize_feature_inputs,
+    metavar="FEATURES...")
+
+
+# Options.
 verbose_opt = click.option(
     '--verbose', '-v',
     count=True,
@@ -36,7 +58,7 @@ quiet_opt = click.option(
 
 # Format driver option.
 format_opt = click.option(
-    '-f', '--format', '--driver',
+    '-f', '--format', '--driver', 'driver',
     default='GTiff',
     help="Output format driver")
 
@@ -84,8 +106,14 @@ sequence_opt = click.option(
     '--sequence/--no-sequence',
     default=False,
     help="Write a LF-delimited sequence of texts containing individual "
-         "objects or write a single JSON text containing a feature "
-         "collection object (the default).")
+    "objects or write a single JSON text containing a feature "
+    "collection object (the default).",
+    callback=lambda ctx, param, value: warn(
+        "Sequences of Features, not FeatureCollections, will be the default in version 1.0.0",
+        FutureWarning,
+    )
+    or value,
+)
 
 use_rs_opt = click.option(
     '--rs/--no-rs',
@@ -96,8 +124,8 @@ use_rs_opt = click.option(
          "(default is False).")
 
 
-# GeoJSON output mode option.
 def geojson_type_collection_opt(default=False):
+    """GeoJSON FeatureCollection output mode"""
     return click.option(
         '--collection',
         'geojson_type',
@@ -107,6 +135,7 @@ def geojson_type_collection_opt(default=False):
 
 
 def geojson_type_feature_opt(default=False):
+    """GeoJSON Feature or Feature sequence output mode"""
     return click.option(
         '--feature',
         'geojson_type',
@@ -116,6 +145,7 @@ def geojson_type_feature_opt(default=False):
 
 
 def geojson_type_bbox_opt(default=False):
+    """GeoJSON bbox output mode"""
     return click.option(
         '--bbox',
         'geojson_type',
